@@ -2,15 +2,11 @@ from abc import ABCMeta, abstractmethod
 from apscheduler.schedulers.background import BackgroundScheduler
 import boto3
 import os
-from . import logger
 import logging
 import pkgutil
 from yaml import load, FullLoader
 logging.getLogger('s3transfer').setLevel(logging.CRITICAL)
 
-# Get log file
-my_logger = logger.logger('ocr')
-
 
 class MLModel(metaclass=ABCMeta):
     def __init__(self, model_name, model_id=None, config_version='current_model', do_not_update=False):
@@ -19,8 +15,6 @@ class MLModel(metaclass=ABCMeta):
         self.do_not_update = do_not_update
         self.model_id = self._get_model_id(model_id)
         self.load_model()
-        my_logger.info('Model {} Loaded'.format(self.model_name))
-        my_logger.info('Model id from manifest '+str(self.model_id))
         self.schedule_model_check()
 
     @staticmethod
@@ -43,7 +37,6 @@ class MLModel(metaclass=ABCMeta):
         :param object_name: S3 object name.
         :return: True if file was uploaded, else False
         """
-        my_logger.info('Uploading file to S3 '+str(file_name))
         s3_client.upload_file(file_name, bucket, object_name)
 
     def _save_new_manifest(self, new_model_id, save_to):
@@ -58,9 +51,6 @@ class MLModel(metaclass=ABCMeta):
             return model_id
 
     def _is_new_manifesto(self, manifest_id):
-        my_logger.info(
-            'Manifest id {new_date}, in-memory id {old_date}'.format(
-                new_date=manifest_id, old_date=self.model_id))
         if manifest_id == self.model_id:
             return 0
         else:
@@ -78,14 +68,11 @@ class MLModel(metaclass=ABCMeta):
         return manifest_id
 
     def _load_if_model_updated(self):
-        my_logger.info('Checking manifest {}'.format(self.model_name))
         manifest_id = self._read_s3_manifest()
         if self._is_new_manifesto(manifest_id):
             self.load_model()
             self.model_id = manifest_id
-            my_logger.info('Loaded latest {} model'.format(self.model_name))
         else:
-            my_logger.info('No updated {} model'.format(self.model_name))
             pass
 
     def schedule_model_check(self):
