@@ -24,9 +24,6 @@ from tensorflow.keras.callbacks import (
     EarlyStopping
 )
 from tensorflow.keras.optimizers import Adam
-from . import logger
-# Get log file
-my_logger = logger.logger('ocr')
 
 tf.disable_eager_execution()
 
@@ -96,7 +93,6 @@ class YOLO(ml_model.MLModel):
         self.classes = classes
 
     def train(self):
-        my_logger.info('I am training YOLO')
         tf.enable_eager_execution()
         class_names = get_classes(self.config['classes_path'])
         num_classes = len(class_names)
@@ -121,8 +117,6 @@ class YOLO(ml_model.MLModel):
             weights_path=weights_path
         )  # make sure you know what you freeze
 
-        my_logger.info('Initial model created using weights '+str(
-            weights_path))
         os.remove(weights_path)
         # Save checkpoints with new version number. Only the checkpoint with
         # highest validation accuracy will be saved.
@@ -151,12 +145,6 @@ class YOLO(ml_model.MLModel):
         num_val = int(len(lines) * val_split)
         num_train = len(lines) - num_val
 
-        my_logger.info(
-            "Train on {}, val on {}, with batch size {}.".format(
-                num_train, num_val, batch_size
-            )
-        )
-
         # Unfreeze and continue training, to fine-tune.
         full_callbacks = [checkpoint, reduce_lr, early_stopping]
 
@@ -165,8 +153,6 @@ class YOLO(ml_model.MLModel):
             loss={"yolo_loss": lambda y_true, y_pred: y_pred}
         )
 
-        my_logger.info("Unfreeze all layers.")
-
         model.fit(
             data_generator_wrapper(
                 lines[:num_train], batch_size, input_shape, anchors,
